@@ -43,6 +43,7 @@ class EFContext(object):
     self._aws_clients = None
     self._commit = None
     self._devel = None
+    self._only_for = None
     self._verbose = None
     self._whereami = whereami()
 
@@ -190,6 +191,15 @@ class EFContext(object):
       raise TypeError("devel value must be bool")
     self._devel = value
 
+  @property
+  def only_for(self):
+    """Specific service registry entry targeted as parameter passed to tool"""
+    return self._only_for
+
+  @only_for.setter
+  def only_for(self, value):
+    self._only_for = value
+
   @property
   def verbose(self):
     """True if the tool should print extra info"""
