@@ -47,6 +47,7 @@ class EFVersionContext(EFContext):
     super(EFVersionContext, self).__init__()
     # core stuff
     self._build_number = None
+    self._pipeline_build_number = None
     self._commit_hash = None
     self._force_env_full = None
     self._get = None
@@ -73,6 +74,17 @@ class EFVersionContext(EFContext):
     """Setter provided because this is writeable from other than init() because --rollback alters it"""
     self._build_number = value
 
+  @property
+  def pipeline_build_number(self):
+    """Externally defined PIPELINE build number associated with version entity"""
+    return self._pipeline_build_number
+
+  @pipeline_build_number.setter
+  def pipeline_build_number(self, value):
+    """Setter provided because this is writeable from other than init() because --rollback alters it"""
+    self._pipeline_build_number = value
+
+
   @property
   def commit_hash(self):
     """Commit hash associated with version entity"""
@@ -183,13 +195,14 @@ class Version(object):
 
     metadata = object_version["Metadata"]
     self._build_number = metadata.get(EFConfig.S3_VERSION_BUILDNUMBER_KEY,"")
+    self._pipeline_build_number = metadata.get(EFConfig.S3_VERSION_PIPELINEBUILDNUMBER_KEY,"")
     self._commit_hash = metadata.get(EFConfig.S3_VERSION_COMMITHASH_KEY,"")
     self._location = metadata.get(EFConfig.S3_VERSION_LOCATION_KEY,"")
     self._modified_by = metadata.get(EFConfig.S3_VERSION_MODIFIEDBY_KEY,"")
     self._status = metadata.get(EFConfig.S3_VERSION_STATUS_KEY,"")
 
   def __str__(self):
-    return "{} {} {} {} {} {} {} {}".format(self._value, self._build_number, self._commit_hash, self._last_modified,
+    return "{} {} {} {} {} {} {} {}".format(self._value, self._build_number, self._pipeline_build_number, self._commit_hash, self._last_modified,
                                             self._modified_by, self._version_id, self._location, self._status)
 
   def __repr__(self):
@@ -202,6 +215,7 @@ class Version(object):
     """
     return {
         "build_number": self._build_number,
+        "pipeline_build_number": self._pipeline_build_number,
         "commit_hash": self._commit_hash,
         "last_modified": self._last_modified,
         "location": self._location,
@@ -215,6 +229,10 @@ class Version(object):
   def build_number(self):
     return self._build_number
 
+  @property
+  def pipeline_build_number(self):
+    return self._pipeline_build_number
+
   @property
   def commit_hash(self):
     return self._commit_hash
@@ -277,6 +295,9 @@ def handle_args_and_set_context(args):
   parser.add_argument("--build",
                       help="On --set, also set the externally defined build number associated with the version entity",
                       default="")
+  parser.add_argument("--pipeline_build",
+                      help="On --set, also set the externally defined PIPELINE build number associated with the version entity",
+                      default="")
   parser.add_argument("--commit_hash", help="On --set, also set the commit hash associated with the version entity",
                       default="")
   parser.add_argument("--commit", help="Actually --set or --rollback (dry run if omitted)",
@@ -298,6 +319,7 @@ def handle_args_and_set_context(args):
   context = EFVersionContext()
   # marshall the inherited context values
   context._build_number = parsed_args["build"]
+  context._pipeline_build_number = parsed_args["pipeline_build"]
   context._commit_hash = parsed_args["commit_hash"]
   context.commit = parsed_args["commit"]
   context.devel = parsed_args["devel"]
@@ -580,6 +602,7 @@ def cmd_set(context):
         Key=s3_key,
         Metadata={
             EFConfig.S3_VERSION_BUILDNUMBER_KEY: context.build_number,
+            EFConfig.S3_VERSION_PIPELINEBUILDNUMBER_KEY: context.pipeline_build_number,
             EFConfig.S3_VERSION_COMMITHASH_KEY: context.commit_hash,
             EFConfig.S3_VERSION_LOCATION_KEY: context.location,
             EFConfig.S3_VERSION_MODIFIEDBY_KEY: context.aws_client("sts").get_caller_identity()["Arn"],
